/*
   AntiRight
   (c) 2003-2004 Jeffrey Bedard
   jefbed@e-list.net
 
   This file is part of AntiRight.

    AntiRight is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    AntiRight is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with AntiRight; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* This is the drawing application programming interface.  It wraps
   xlib's drawing functions.  */

#include "library.h"

void
antiright_drawing_initialize(Widget drawing_widget, 
			     struct antiright_drawing_structure *drawing)
{
  drawing->display=XtDisplay(drawing_widget);
  drawing->window=XtWindow(drawing_widget);
  drawing->gc=XCreateGC(drawing->display,
			drawing->window,
			0,
			NULL);

  ARCLARG;
  antiright_set(XmNheight, (XtArgVal)&drawing->height);
  antiright_set(XmNwidth, (XtArgVal)&drawing->width);
  XtGetValues(drawing_widget,
	      antiright_arguments, antiright_number_arguments);
}

void
antiright_drawing_finish(struct antiright_drawing_structure *drawing)
{
  XFreeGC(drawing->display, drawing->gc);
}

void
antiright_draw_line(struct antiright_drawing_structure *drawing,
		    int x1, int y1,
		    int x2, int y2)
{
  XDrawLine(drawing->display, drawing->window, drawing->gc, 
	    x1, y1, 
	    x2, y2);
}

void
antiright_draw_string(struct antiright_drawing_structure *drawing,
		      int x, int y,
		      char *string)
{
  XDrawString(drawing->display, drawing->window, drawing->gc, 
	      x, y,
	      string, 
	      strlen(string));
}

void
antiright_draw_clear(struct antiright_drawing_structure *drawing)
{
  XClearWindow(drawing->display, drawing->window);
}

void
antiright_draw_flush(struct antiright_drawing_structure *drawing)
{
  XFlush(drawing->display);
}

void
antiright_draw_arc(struct antiright_drawing_structure *drawing,
		   int x, int y,
		   unsigned int width, unsigned int height,
		   int angle1, int angle2)
{
  XDrawArc(drawing->display, drawing->window, drawing->gc, 
	   x, y, 
	   width, height, 
	   angle1, angle2);
}

void
antiright_draw_filled_arc(struct antiright_drawing_structure *drawing,
			  int x, int y,
			  unsigned int width, unsigned int height,
			  int angle1, int angle2)
{
  XFillArc(drawing->display, drawing->window, drawing->gc, 
	   x, y, 
	   width, height, 
	   angle1, angle2);
}

void
antiright_draw_allocate_color(struct antiright_drawing_structure *drawing,
			      XColor *color)
{
  Colormap colormap;
  
  /* These options are set often enough, so set them in this generic
     function.  */
  color->flags=DoRed|DoGreen|DoBlue;
  colormap=DefaultColormap(drawing->display, DefaultScreen(drawing->display));
  XAllocColor(drawing->display, colormap, color);
}

void
antiright_draw_foreground(struct antiright_drawing_structure *drawing,
			  int red_int, int green_int, int blue_int)
{
  XColor color;

  color.red=red_int*256;
  color.green=green_int*256;
  color.blue=blue_int*256;
  antiright_draw_allocate_color(drawing, &color);
  XSetForeground(drawing->display, drawing->gc, color.pixel);
}
